'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'' viewRTC.spin
'' A program to set the clock for the MGH Designs DNA-RTC board.
''
'' This uses the:
''     S-35390A RTC driver by Roy Eltham
''     Basic_I2C_Driver by Michael Green

CON
  _clkmode = xtal1 + pll16x
  _clkfreq = 80_000_000

'' For use of debug terminal screen.    
  rxPin    = 31
  txPin    = 30
  mode     = 0
  baudrate = 115200
  


OBJ
  rtc  : "s-35390A"
  term : "Extended_FDSerial"
  misc : "tools"

VAR
  long vmonth,vday,vyear,vdayofweek,vhour,vminutes,vseconds,inbyte,hourmode

PUB Start
  term.Start(rxPin, txPin, mode, baudrate)
  misc.waitms(500)

'' Refresh the RTC  
  rtc.Update
  
  main
  
'' Start the UI session
PUB main | inString, inAbyte
  term.Str(string("This is viewRTC.",13,10))
  Date
  Time
  term.str(string("Menu: help - full menu, quit - end program ",13,10)) 
  repeat
    term.Tx("#")
    term.RxStr(@inStrg)
    if strcomp(@inStrg, @stopProg)
      CRLF
      term.str(string(10,"Program Stopped",13))
      abort
    elseif strcomp(@inStrg, @help)
      Menu
    elseif strcomp(@inStrg, @intime)
      Time
    elseif strcomp(@inStrg, @indate)
      Date
    elseif strcomp(@inStrg, @dosetclk)
      SetClock
    elseif strcomp(@inStrg, @dosettime)
      SetTime
    elseif strcomp(@inStrg, @do24or12)
      Set2412Mode
    else
      term.str(string(13,"Invalid Command!",13))

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
PUB Menu
  term.str(string("Menu: help - this menu, quit - end program ",13,10))
  term.str(string("      time, date, setclock, settime, set2412",13,10))
  

PUB SetClock 

  term.Tx(0) ' Clear screen
  term.str(string("Enter month:"))
  inbyte := term.RxDec
  vmonth := inbyte
  term.str(string(13,10,"Enter day:"))
  inbyte := term.RxDec
  vday := inbyte
  term.str(string(13,10,"Enter year:"))
  inbyte := term.RxDec
  vyear := inbyte
  term.str(string(13,10,"DOW:0-su,1-mo,2-tu,3-we,4-th,5-fr,6-sa",13,10))
  term.str(string("Enter dow:"))
  inbyte := term.RxDec
  vdayofweek := inbyte
  term.str(string(13,10,"Enter hour:"))
  inbyte := term.RxDec
  vhour := inbyte
  term.str(string(13,10,"Enter minutes:"))
  inbyte := term.RxDec
  vminutes := inbyte
  term.str(string(13,10,"Enter seconds:"))
  inbyte := term.RxDec
  vseconds := inbyte
  rtc.SetDateTime(vmonth, vday, vyear, vdayOfWeek, vhour, vminutes, vseconds)
  Date
  Time
  
PUB SetTime
  term.Tx(0) ' Clear screen
  term.str(string("Enter hour:"))
  inbyte := term.RxDec
  vhour := inbyte
  term.str(string(13,10,"Enter minutes:"))
  inbyte := term.RxDec
  vminutes := inbyte
  term.str(string(13,10,"Enter seconds:"))
  inbyte := term.RxDec
  vseconds := inbyte
  rtc.SetTime(vhour, vminutes, vseconds)
  CRLF
  Time


PUB Date | year,month,day 
  year := rtc.GetYear
  month := rtc.GetMonth
  day := rtc.GetDay
  
  term.Dec(month)
  term.Str(string("/"))
  term.Dec(day)
  term.Str(string("/20"))  
  term.Dec(year)
  CRLF
  
PUB Time | hour,minutes,seconds
  hour := rtc.GetHour
  minutes := rtc.GetMinutes
  seconds := rtc.GetSeconds
  
  term.Dec(hour)
  term.Str(string(":"))
  term.Dec(minutes)
  term.Str(string(":"))
  term.Dec(seconds)
  CRLF  

PUB Set2412Mode
  term.Tx(0) ' Clear screen
  term.str(string("1 = 24 hour,0 = 12 hour",13,10))
  term.str(string("Hour mode:"))
  inbyte := term.RxDec
  hourmode := inbyte
  rtc.Set24HourMode(hourmode)
  CRLF
  Time  
  
PUB CRLF
  term.Tx(13)
  term.Tx(10)

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
DAT
inStrg byte "               ",0
stopProg byte "quit",0
help byte "help",0
intime byte "time",0
indate byte "date",0
dosetclk byte "setclock",0
dosettime byte "settime",0
dosetdate byte "setdate",0
do24or12 byte "set2412",0
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''